.. _renderers:

=========
Renderers
=========

The section contains an overview of all the plots
that are included in cgatreport. CGATReport includes
access to several plotting frontends.

.. toctree::
   :maxdepth: 2

   GalleryTabular.rst
   GallerySeaborn.rst
   GalleryGGPlot.rst
   GalleryPDPlot.rst
   GalleryR.rst
   GalleryBokeh.rst
   GallerySpecial.rst
